mmusicc.formats package
=======================

.. important:: Make sure to call ``formats.init()`` before using the modules automatic loading functions/classes!

Module contents
---------------

.. automodule:: mmusicc.formats
    :members:
    :special-members: mimes

.. hint:: the following attributes are imported in __init__. I don't know how to document them with their docstring as I did with init and MusicFile.

.. automodule:: mmusicc.formats._misc

mmusicc.formats._audio module
-----------------------------

.. automodule:: mmusicc.formats._audio
   :members:
   :undoc-members:
   :show-inheritance:

mmusicc.formats.mp3 module
--------------------------

.. automodule:: mmusicc.formats.mp3
   :members:
   :undoc-members:
   :show-inheritance:

mmusicc.formats.xiph module
---------------------------

.. automodule:: mmusicc.formats.xiph
   :members:
   :undoc-members:
   :show-inheritance:
